@@ -78,7 +78,7 @@ class Blueberry(Gtk.Application):
         self.window.connect("destroy", self.terminate)
         self.window.set_default_size(640, 400)
 
-        self.main_box = Gtk.VBox()
+        self.main_box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
 
         # Toolbar
         toolbar = Gtk.Toolbar()
@@ -111,7 +111,7 @@ class Blueberry(Gtk.Application):
             debug = True
 
         # Devices
-        self.devices_box = Gtk.VBox()
+        self.devices_box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
         self.devices_box.set_border_width(12)
 
         self.rf_switch = Gtk.Switch()
@@ -133,8 +133,8 @@ class Blueberry(Gtk.Application):
         self.lib_widget.show()
         self.stack.show();
 
-        switchbox = Gtk.VBox()
-        hbox = Gtk.HBox()
+        switchbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
+        hbox = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL)
         hbox.pack_end(self.rf_switch, False, False, 10)
         switchbox.pack_start(hbox, False, False, 0)
         switchbox.pack_start(self.status_image, False, False, 0)
@@ -151,7 +151,9 @@ class Blueberry(Gtk.Application):
 
         section = page.add_section(_("Bluetooth settings"))
         self.adapter_name_entry = Gtk.Entry()
-        self.adapter_name_entry.set_text(self.get_default_adapter_name())
+        adapter_name = self.get_default_adapter_name()
+        if adapter_name is not None:
+            self.adapter_name_entry.set_text(adapter_name)
         self.adapter_name_entry.connect("changed", self.on_adapter_name_changed)
         row = SettingsRow(Gtk.Label(_("Name")), self.adapter_name_entry)
         row.set_tooltip_text(_("This is the Bluetooth name of your computer"))
@@ -169,9 +171,7 @@ class Blueberry(Gtk.Application):
         self.tray_switch.set_active(self.settings.get_boolean("tray-enabled"))
         self.tray_switch.connect("notify::active", self.on_tray_switch_toggled)
         self.settings.connect("changed", self.on_settings_changed)
-        if self.de != "Cinnamon":
-            # In Cinnamon we're using an applet instead
-            section.add_row(SettingsRow(Gtk.Label(_("Show a tray icon")), self.tray_switch))
+        section.add_row(SettingsRow(Gtk.Label(_("Show a tray icon")), self.tray_switch))
 
         self.window.add(self.main_box)
 
@@ -228,12 +228,15 @@ class Blueberry(Gtk.Application):
 
     def get_default_adapter_name(self):
         name = None
-        output = subprocess.check_output(["bt-adapter", "-i"]).strip()
-        for line in output.split("\n"):
-            line = line.strip()
-            if line.startswith("Alias: "):
-                name = line.replace("Alias: ", "").replace(" [rw]", "").replace(" [ro]", "")
-                break
+        try:
+            output = subprocess.check_output(["bt-adapter", "-i"]).strip()
+            for line in output.split("\n"):
+                line = line.strip()
+                if line.startswith("Alias: "):
+                    name = line.replace("Alias: ", "").replace(" [rw]", "").replace(" [ro]", "")
+                    break
+        except Exception as cause:
+            print ("Could not retrieve the BT adapter name with 'bt-adapter -i': %s" % cause)
         return name
 
     def update_status(self, path=None, iter=None, data=None):
